pub struct Client { /* private fields */ }Expand description
A Client to make Requests with.
The Client has various configuration values to tweak, but the defaults
are set to what is usually the most commonly desired value. To configure a
Client, use Client::builder().
The Client holds a connection pool internally, so it is advised that
you create one and reuse it.
Examples
use slinger::Client;
let client = Client::new();
let resp = client.get("http://httpbin.org/").send().await?;
Implementations
Sourceimpl Client
impl Client
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Creates a ClientBuilder to configure a Client.
This is the same as ClientBuilder::default().
Sourcepub fn get<U>(&self, url: U) -> RequestBuilder
pub fn get<U>(&self, url: U) -> RequestBuilder
Convenience method to make a GET request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn post<U>(&self, url: U) -> RequestBuilder
pub fn post<U>(&self, url: U) -> RequestBuilder
Convenience method to make a POST request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn put<U>(&self, url: U) -> RequestBuilder
pub fn put<U>(&self, url: U) -> RequestBuilder
Convenience method to make a PUT request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn patch<U>(&self, url: U) -> RequestBuilder
pub fn patch<U>(&self, url: U) -> RequestBuilder
Convenience method to make a PATCH request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn delete<U>(&self, url: U) -> RequestBuilder
pub fn delete<U>(&self, url: U) -> RequestBuilder
Convenience method to make a DELETE request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn head<U>(&self, url: U) -> RequestBuilder
pub fn head<U>(&self, url: U) -> RequestBuilder
Convenience method to make a HEAD request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn trace<U>(&self, url: U) -> RequestBuilder
pub fn trace<U>(&self, url: U) -> RequestBuilder
Convenience method to make a TRACE request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn connect<U>(&self, url: U) -> RequestBuilder
pub fn connect<U>(&self, url: U) -> RequestBuilder
Convenience method to make a CONNECT request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn options<U>(&self, url: U) -> RequestBuilder
pub fn options<U>(&self, url: U) -> RequestBuilder
Convenience method to make a OPTIONS request to a URL.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn request<U>(&self, method: Method, url: U) -> RequestBuilder
pub fn request<U>(&self, method: Method, url: U) -> RequestBuilder
Start building a Request with the Method and Uri.
Returns a RequestBuilder, which will allow setting headers and
request body before sending.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub fn raw<U, R>(&self, uri: U, raw: R, unsafe_raw: bool) -> RequestBuilder
pub fn raw<U, R>(&self, uri: U, raw: R, unsafe_raw: bool) -> RequestBuilder
Start building a Request with the Method and Uri.
Returns a RequestBuilder, which will allow setting headers and
request body before sending.
Errors
This method fails whenever supplied Uri cannot be parsed.
Sourcepub async fn execute_request(
&self,
socket_opt: Option<Socket>,
request: &Request,
) -> Result<(Response, Option<Socket>)>
pub async fn execute_request( &self, socket_opt: Option<Socket>, request: &Request, ) -> Result<(Response, Option<Socket>)>
Executes a Request.
A Request can be built manually with Request::new() or obtained
from a RequestBuilder with RequestBuilder::build().
You should prefer to use the RequestBuilder and
RequestBuilder::send().
Errors
This method fails if there was an error while sending request, or redirect limit was exhausted.
Sourcepub async fn execute<R: Into<Request>>(&self, request: R) -> Result<Response>
pub async fn execute<R: Into<Request>>(&self, request: R) -> Result<Response>
Executes a Request.
A Request can be built manually with Request::new() or obtained
from a RequestBuilder with RequestBuilder::build().
You should prefer to use the RequestBuilder and
RequestBuilder::send().
Errors
This method fails if there was an error while sending request, or redirect limit was exhausted.